@@ -1,7 +1,6 @@
 import logging
 
 from app.config import ProcMuxConfig
-from app.context import ProcMuxContext
 from app.log import formatter, logger
 
 
@@ -11,8 +10,5 @@ def run_app(cfg: ProcMuxConfig):
         file_handler.setLevel(logging.DEBUG)
         file_handler.setFormatter(formatter)
         logger.addHandler(file_handler)
-    ProcMuxContext().bootstrap(cfg)
     from app.tui.app import start_tui
-    start_tui()
-
-
+    start_tui(cfg)
